# Changelog

## 0.2.2 2023 Dec 2

- bugfix in compat tool
  former hide_input → new remove-input, not hide-input

## 0.2.1 2023 Dec 2

- rename compat tool into hideinput-to-hidecell
- and get it to actually work

## 0.2.0 2023 Dec 2

- a reasonable implementation, but static:
  have not been able to implement the jupyter-book togglers
- shortcut keys all begin with `Accel-0`, see palette

## 0.1.3 2023 Nov 28

- merged #4 - keyboard shortcuts are now in the form
  Alt-1 Alt-2 etc, or just Alt-0

## 0.1.2 2023 Nov 27

- expose command `split-cell-to-hidecell` to convert notebooks

## 0.1.1 2023 Nov 27

- initial release
